==> icons-vue-0.6.0.tgz: package/es/watson-health/window--base/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_WatsonHealthWindowBase20 = {
  name: 'WatsonHealthWindowBase20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "15",
        "y": "2"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "25",
        "y": "13"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "15",
        "y": "23"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "4",
        "y": "13"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "7.55",
        "y": "5.03",
        "transform": "rotate(-45 8.56 6.544)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "21.96",
        "y": "5.54",
        "transform": "rotate(-45 23.469 6.539)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "22.46",
        "y": "19.94",
        "transform": "rotate(-45 23.462 21.442)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "7.04",
        "y": "20.45",
        "transform": "rotate(-45 8.554 21.447)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "24",
        "height": "2",
        "x": "4",
        "y": "28"
      }
    }), createElement('path', {
      attrs: {
        "d": "M16,20a6,6,0,1,0-6-6A6,6,0,0,0,16,20Zm0-10v8a4,4,0,0,1,0-8Z"
      }
    }), children]);
  }
};

export default virtual_WatsonHealthWindowBase20;

==> icons-vue-10.6.1.tgz: package/es/watson-health/window--base/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../../chunk-75bb93d0.js';
import { getAttributes } from '@carbon/icon-helpers';

var virtual_WatsonHealthWindowBase20 = {
  name: 'WatsonHealthWindowBase20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M15 2h2v3h-2zm10 11h3v2h-3zM15 23h2v3h-2zM4 13h3v2H4zm2.775-6.812L8.19 4.773l2.122 2.122-1.414 1.414zm14.921.712l2.12-2.122 1.415 1.415-2.121 2.12zm-.005 14.188l1.415-1.414 2.12 2.122-1.413 1.414zm-14.913.725L8.9 19.69l1.414 1.414-2.121 2.122zM4 28h24v2H4zm12-8a6 6 0 1 0-6-6 6 6 0 0 0 6 6zm0-10v8a4 4 0 0 1 0-8z"
      }
    }), children]);
  }
};

export default virtual_WatsonHealthWindowBase20;
